@@ -1,5 +1,5 @@
-Bchronology <-
-function(ages,ageSds,positions,positionThicknesses=rep(0,length(ages)),calCurves=rep('intcal13',length(ages)),ids=NULL,outlierProbs=rep(0.01,length(ages)),predictPositions=seq(min(positions),max(positions),length=100),pathToCalCurves=system.file('data',package='Bchron'),iterations=10000,burn=2000,thin=8,extractDate=1950-as.numeric(format(Sys.time(),"%Y")),maxExtrap=500,thetaMhSd=0.5,muMhSd=0.1,psiMhSd=0.1,ageScaleVal=1000,positionScaleVal=100) {
+# Function to create Bchron chronologies
+Bchronology = function(ages,ageSds,positions,positionThicknesses=rep(0,length(ages)),calCurves=rep('intcal13',length(ages)),ids=NULL,outlierProbs=rep(0.01,length(ages)),predictPositions=seq(min(positions),max(positions),length=100),pathToCalCurves=system.file('data',package='Bchron'),iterations=10000,burn=2000,thin=8,extractDate=1950-as.numeric(format(Sys.time(),"%Y")),maxExtrap=500,thetaMhSd=0.5,muMhSd=0.1,psiMhSd=0.1,ageScaleVal=1000,positionScaleVal=100) {
   
 # Notation:
 # theta are the calibrated ages of ages 1 to n (not necessarily radiocarbon)
@@ -40,7 +40,7 @@ do = order(currPositions)
 # For any calibration curves that don't start at 0, we need an offset to enable fast lookup - only supported one so far is normal
 offset=rep(0,length=n)
 for(i in 1:n) {
-   offset[i] = ifelse(x.df1[[i]]$calCurve == 'normal',61,0)
+   offset[i] = ifelse(x.df1[[i]]$calCurve == 'normal',100+1,0)
 }
 
 # Starting values
@@ -164,6 +164,7 @@ for(i in 1:iterations) {
     if(runif(1)<exp(logRtheta)) theta[do[j]] = thetaNew      
   }
   
+  
   # Update phi
   for(j in 1:n) {
     phiNew = sample(0:1,1)
@@ -210,4 +211,4 @@ out = list(theta=thetaStore,phi=phiStore,mu=muStore,psi=psiStore,thetaPredict=ag
 class(out) = 'BchronologyRun'
 return(out)
   
-}
+}
\ No newline at end of file
